# antenny-cdk

antenny-cdk is a cloud development kit construct library for Antenny. It provides a way to integrate Antenny into your cdk infrastructure.

## Installation

#### npm

```shell
npm install antenny-cdk --save
```

#### pip

```shell
pip install antenny-cdk
```

#### nuget

```shell
dotnet add package Antenny.Cdk
```
